==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.docx4j/src/pptx4j/java/org/pptx4j/pml_2012/ObjectFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.pptx4j.pml_2012;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;

@XmlRegistry
public class ObjectFactory {

    private final static QName _threadingInfo_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2012/main", "threadingInfo");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.pptx4j.pml_2012;
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CTCommentThreading }
     * 
     */
    public CTCommentThreading createCTThreadingInfo() {
        return new CTCommentThreading();
    }

    /**
     * Create an instance of {@link CTParentCommentIdentifier }
     * 
     */
    public CTParentCommentIdentifier createCTParentCommentIdentifier() {
        return new CTParentCommentIdentifier();
    }
    
    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTWorksheet }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2012/main", name = "threadingInfo")
    public JAXBElement<CTCommentThreading> createMacrosheet(CTCommentThreading value) {
        return new JAXBElement<CTCommentThreading>(_threadingInfo_QNAME, CTCommentThreading.class, null, value);
    }
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.docx4j/src/pptx4j/java/org/pptx4j/pml_2012/ObjectFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.pptx4j.pml_2012;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;

@XmlRegistry
public class ObjectFactory {

    private final static QName _presenceInfo_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2012/main", "presenceInfo");
    private final static QName _threadingInfo_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2012/main", "threadingInfo");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.pptx4j.pml_2012;
     *
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CTPresenceInfo }
     *
     */
    public CTPresenceInfo createCTPresenceInfo() {
        return new CTPresenceInfo();
    }

    /**
     * Create an instance of {@link CTCommentThreading }
     *
     */
    public CTCommentThreading createCTThreadingInfo() {
        return new CTCommentThreading();
    }

    /**
     * Create an instance of {@link CTParentCommentIdentifier }
     *
     */
    public CTParentCommentIdentifier createCTParentCommentIdentifier() {
        return new CTParentCommentIdentifier();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTWorksheet }{@code >}}
     *
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2012/main", name = "presenceInfo")
    public JAXBElement<CTPresenceInfo> createMacrosheet(CTPresenceInfo value) {
        return new JAXBElement<CTPresenceInfo>(_presenceInfo_QNAME, CTPresenceInfo.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTWorksheet }{@code >}}
     *
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2012/main", name = "threadingInfo")
    public JAXBElement<CTCommentThreading> createMacrosheet(CTCommentThreading value) {
        return new JAXBElement<CTCommentThreading>(_threadingInfo_QNAME, CTCommentThreading.class, null, value);
    }
}
